#include "pixelwindow.h"
#include "ui_pixelwindow.h"
#include <QDebug>
#include <QPainter>

//int c;
//int d;




pixelWindow::pixelWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::pixelWindow)
{
    ui->setupUi(this);
    setAttribute(Qt::WA_Maemo5StackedWindow);
    setAttribute(Qt::WA_DeleteOnClose);

}

pixelWindow::~pixelWindow()
{
    delete ui;
}

void pixelWindow::on_pushButton_clicked()
{
    close();
}

void pixelWindow::mouseMoveEvent( QMouseEvent *event)
{

    int c;
    int d;
    c = event->x();
    d = event->y();
   ui->label->setText("x "+ QString::number(c) + "   y " + QString::number(d));

    discposition = event->pos();
    update();


}

void pixelWindow::paintEvent()
{

  QPainter painter(this);

    painter.setPen ( QPen (Qt::white, 1) );
    //painter.setBrush ( QBrush (Qt::white, Qt::Dense4Pattern) );

    painter.drawEllipse (discposition.x()-10, discposition.y()-10,20, 20);



}
